#
# spec file for package apache2-mod_bmx
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if %{defined suse_version}
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-prefork
BuildRequires:  apache2-worker
%else
%define apache_apxs %{_sbindir}/apxs
BuildRequires:  httpd-devel
%endif
BuildRequires:  curl
Name:           apache2-mod_bmx
Version:        0.9.6
Release:        2.37
Summary:        Internal Apache Runtime Statistics Module
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            https://github.com/hyperic/mod_bmx
# https://github.com/hyperic/mod_bmx/tarball/%%{version}
Source:         https://github.com/hyperic/mod_bmx/archive/%{version}.tar.gz
Source1:        apache2-mod_bmx.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{defined suse_version}
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
%else
Requires:       httpd
%endif

%description
BMX is a framework for Apache to provide internal runtime statistics
and configuration information to interested remote agents. It can
be used to report on the internal workings and status of Apache at
runtime, such as performance metrics and current capacity.

%package doc
Summary:        Module Documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description doc
Provides manual for bmx module inside Apache documentation directory.

%prep
%setup -q -n mod_bmx-%{version}

%build
APXS="%{apache_apxs}" \
./configure.apxs
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm "%{buildroot}%{apache_libexecdir}/mod_bmx_example.so"
install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_sysconfdir}/apache2/conf.d/mod_bmx.conf"

%check
set +x
exit_code=0
# world writeable dir (/tmp subdir)
mkdir -p %{apache_test_module_dir}
# create test configuration file
cat << EOF  > %{apache_test_module_dir}/mod_bmx-test.conf
<Location /bmx>
  SetHandler bmx-handler
%if 0%{?apache_branch} >= 204
  Require local
%else
  Allow from localhost
%endif
</Location>
EOF
# start test apache instance
%apache_test_module_start_apache -m bmx:bmx_status -i mod_bmx-test.conf
# curl test document
%apache_test_module_curl -d /bmx -o %{apache_test_module_dir}/bmx.txt
# perform test on curl output ---
echo
echo 'Testing /bmx output:'
grep 'ServerName' %{apache_test_module_dir}/bmx.txt || exit_code=1
grep 'ServerVersion: Apache.*SUSE' %{apache_test_module_dir}/bmx.txt || exit_code=1
if [ $exit_code -eq 0 ]; then
  echo 'SUCCESS'
else
  echo 'FAILED'
fi
echo
# stop test apache instance
%apache_test_module_stop_apache
set -x
# exit the result
exit $exit_code

%postun
# request restart apache instanaces (which loaded bmx) after apache2-mod_bmx package update
if [ $1 -eq 1 ]; then
  %apache_request_restart -m bmx
fi

%posttrans
# restart apache instances which have this module after zypper or rpm transaction, if not
# have restarted already in other posttrans
%apache_restart_if_needed

%files
%defattr(-,root,root)
%doc *.txt
%config(noreplace) %{_sysconfdir}/apache2/conf.d/mod_bmx.conf
%{apache_libexecdir}/mod_bmx.so
%{apache_libexecdir}/mod_bmx_status.so
%{apache_libexecdir}/mod_bmx_vhost.so

%files doc
%defattr(-,root,root)
%dir %{_datadir}/%{apache_pname}
%dir %{_datadir}/%{apache_pname}/manual
%dir %{_datadir}/%{apache_pname}/manual/mod
%{_datadir}/%{apache_pname}/manual/mod/mod_bmx*

%changelog
* Tue Jan 12 2016 pgajdos@suse.com
-  %%check: access syntax depends rather on %%{apache_branch}, as test
  does not use system setting (/etc/apache2) at all
* Thu Nov 19 2015 pgajdos@suse.com
- version update 0.9.6
  * Correctly traverse all servers when reporting status
  * Distinguish identical hostnames across multiple ports
  * Introduce httpd project styled docs for merging into httpd/manual
* Wed Nov 11 2015 pgajdos@suse.com
- restart apache during upgrade
* Fri Oct  2 2015 pgajdos@suse.com
- fix test
* Tue Sep 15 2015 pgajdos@suse.com
- use %%{apache_access_syntax_version} macro while creating test conf
* Sat Sep  5 2015 pgajdos@suse.com
- test module with %%apache_test_module_curl
* Mon Aug 31 2015 pgajdos@suse.com
- test module with %%apache_test_module
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Thu Jun  4 2015 pgajdos@suse.com
- access configuration conditional
  * modified apache2-mod_bmx.conf
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Tue Jun 26 2012 pascal.bleser@opensuse.org
- initial version (0.9.4)
